<?xml version='1.0' encoding='UTF-8'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0">
  <xsl:template name="genPath">
    <xsl:param name="prevPath"/>
    <xsl:variable name="currPath" select="concat('/',name(),'[', count(preceding-sibling::*[name() = name(current())])+1,']',$prevPath)"/>
    <xsl:for-each select="parent::*">
      <xsl:call-template name="genPath">
        <xsl:with-param name="prevPath" select="$currPath"/>
      </xsl:call-template>
    </xsl:for-each>
    <xsl:if test="not(parent::*)">
      <xsl:value-of select="$currPath"/>
    </xsl:if>
  </xsl:template>
  <xsl:strip-space elements="*"/>
  <xsl:template match="/">
    <warnings>
      <xsl:apply-templates select="//@*|node()"/>
    </warnings>
  </xsl:template>
  <xsl:template match="@*|text()"/>
  <xsl:template match="Package/@xsi:noNamespaceSchemaLocation[.='LIXI-DAS-2_2_7-Annotated.xsd']">
    <updated>
      <xsl:attribute name="name">xsi:noNamespaceSchemaLocation</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LIXI-DAS-2_2_7-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="update">LIXI-DAS-2_2_6-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@LevelType">
    <removed>
      <xsl:attribute name="name">LevelType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@ToStreetNumber">
    <removed>
      <xsl:attribute name="name">ToStreetNumber</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@ToUnitNumber">
    <removed>
      <xsl:attribute name="name">ToUnitNumber</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@UnitType">
    <removed>
      <xsl:attribute name="name">UnitType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Arterial']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Arterial</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Banan']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Banan</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Boardwalk']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Boardwalk</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Boulevarde']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Boulevarde</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Cluster']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Cluster</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Connection']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Connection</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Course']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Course</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Dene']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Dene</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Divide']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Divide</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Dock']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Dock</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Domain']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Domain</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Firebreak']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Firebreak</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Fireline']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Fireline</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Firetrack']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Firetrack</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Ford']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Ford</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Gateway']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Gateway</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Harbour']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Harbour</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Heath']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Heath</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Hollow']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Hollow</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Keys']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Keys</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Manor']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Manor</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Outlet']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Outlet</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Pursuit']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Pursuit</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Return']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Return</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Rising']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Rising</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Shunt']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Shunt</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Throughway']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Throughway</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Twist']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Twist</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Upper']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Upper</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Waterway']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Waterway</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/Standard/@StreetType[.='Woods']">
    <removed>
      <xsl:attribute name="name">StreetType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Woods</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/@ClearingFromOtherSourceAmount">
    <removed>
      <xsl:attribute name="name">ClearingFromOtherSourceAmount</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/@ClearingFromThisLoanAmount">
    <removed>
      <xsl:attribute name="name">ClearingFromThisLoanAmount</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/PercentOwned/Owner/@OwnerType">
    <removed>
      <xsl:attribute name="name">OwnerType</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/Security/MortgagorDetails/@ReasonForDifferentName">
    <removed>
      <xsl:attribute name="name">ReasonForDifferentName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/@x_Account">
    <removed>
      <xsl:attribute name="name">x_Account</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/SchemaVersion/@LIXIVersion[.='2.2.7']">
    <updated>
      <xsl:attribute name="name">LIXIVersion</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">2.2.7</xsl:attribute>
      <xsl:attribute name="update">2.2.6</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
</xsl:stylesheet>
