<?xml version='1.0' encoding='UTF-8'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0">
  <xsl:template name="genPath">
    <xsl:param name="prevPath"/>
    <xsl:variable name="currPath" select="concat('/',name(),'[', count(preceding-sibling::*[name() = name(current())])+1,']',$prevPath)"/>
    <xsl:for-each select="parent::*">
      <xsl:call-template name="genPath">
        <xsl:with-param name="prevPath" select="$currPath"/>
      </xsl:call-template>
    </xsl:for-each>
    <xsl:if test="not(parent::*)">
      <xsl:value-of select="$currPath"/>
    </xsl:if>
  </xsl:template>
  <xsl:strip-space elements="*"/>
  <xsl:template match="/">
    <warnings>
      <xsl:apply-templates select="//@*|node()"/>
    </warnings>
  </xsl:template>
  <xsl:template match="@*|text()"/>
  <xsl:template match="Package/@xsi:noNamespaceSchemaLocation[.='LIXI-DAS-2_1_0-Annotated.xsd']">
    <updated>
      <xsl:attribute name="name">xsi:noNamespaceSchemaLocation</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LIXI-DAS-2_1_0-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="update">LIXI-DAS-2_2_0-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Address/@Country[.='AN']">
    <removed>
      <xsl:attribute name="name">Country</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AN</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/@RegisteredInCountry[.='AN']">
    <removed>
      <xsl:attribute name="name">RegisteredInCountry</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AN</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Beyond Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Beyond Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Broken Hill Community Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Broken Hill Community Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Coastline Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Coastline Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Credit Union SA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Credit Union SA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Defence Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Defence Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Dnister Ukrainian Credit Co-operative']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Dnister Ukrainian Credit Co-operative</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='EECU']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EECU</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Fire Service Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Fire Service Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='First Choice Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='INC Invest']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">INC Invest</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Intech Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Intech Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.=&quot;People's Choice Credit Union&quot;]">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">People's Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Pulse Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Pulse Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Qudos Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Qudos Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Summerland Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Summerland Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Beyond Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Beyond Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Broken Hill Community Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Broken Hill Community Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Coastline Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Coastline Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Credit Union SA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Credit Union SA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Defence Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Defence Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Dnister Ukrainian Credit Co-operative']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Dnister Ukrainian Credit Co-operative</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='EECU']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EECU</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Fire Service Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Fire Service Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='First Choice Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='INC Invest']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">INC Invest</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Intech Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Intech Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.=&quot;People's Choice Credit Union&quot;]">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">People's Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Pulse Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Pulse Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Qudos Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Qudos Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Summerland Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Summerland Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Beyond Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Beyond Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Broken Hill Community Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Broken Hill Community Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Coastline Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Coastline Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Credit Union SA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Credit Union SA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Defence Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Defence Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Dnister Ukrainian Credit Co-operative']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Dnister Ukrainian Credit Co-operative</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='EECU']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EECU</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Fire Service Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Fire Service Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='First Choice Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='INC Invest']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">INC Invest</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Intech Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Intech Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.=&quot;People's Choice Credit Union&quot;]">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">People's Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Pulse Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Pulse Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Qudos Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Qudos Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Summerland Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Summerland Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Beyond Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Beyond Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Broken Hill Community Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Broken Hill Community Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Coastline Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Coastline Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Credit Union SA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Credit Union SA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Defence Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Defence Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Dnister Ukrainian Credit Co-operative']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Dnister Ukrainian Credit Co-operative</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='EECU']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EECU</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Fire Service Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Fire Service Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='First Choice Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='INC Invest']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">INC Invest</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Intech Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Intech Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.=&quot;People's Choice Credit Union&quot;]">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">People's Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Pulse Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Pulse Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Qudos Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Qudos Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Summerland Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Summerland Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Beyond Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Beyond Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Broken Hill Community Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Broken Hill Community Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Coastline Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Coastline Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Credit Union SA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Credit Union SA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Defence Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Defence Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Dnister Ukrainian Credit Co-operative']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Dnister Ukrainian Credit Co-operative</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='EECU']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EECU</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Fire Service Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Fire Service Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='First Choice Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='INC Invest']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">INC Invest</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Intech Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Intech Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.=&quot;People's Choice Credit Union&quot;]">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">People's Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Pulse Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Pulse Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Qudos Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Qudos Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Summerland Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Summerland Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Beyond Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Beyond Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Broken Hill Community Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Broken Hill Community Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Coastline Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Coastline Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Credit Union SA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Credit Union SA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Defence Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Defence Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Dnister Ukrainian Credit Co-operative']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Dnister Ukrainian Credit Co-operative</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='EECU']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EECU</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Fire Service Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Fire Service Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='First Choice Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='INC Invest']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">INC Invest</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Intech Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Intech Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.=&quot;People's Choice Credit Union&quot;]">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">People's Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Pulse Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Pulse Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Qudos Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Qudos Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Summerland Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Summerland Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/OtherIncome/@Country[.='AN']">
    <removed>
      <xsl:attribute name="name">Country</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AN</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/@Citizenship[.='AN']">
    <removed>
      <xsl:attribute name="name">Citizenship</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AN</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/@PrincipalForeignResidence[.='AN']">
    <removed>
      <xsl:attribute name="name">PrincipalForeignResidence</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AN</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/Employment/SelfEmployed/@BusinessStructure">
    <removed>
      <xsl:attribute name="name">BusinessStructure</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/Employment/SelfEmployed/@NumberOfPartners">
    <removed>
      <xsl:attribute name="name">NumberOfPartners</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/Employment/SelfEmployed/Partner">
    <removed>
      <xsl:attribute name="name">Partner</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Beyond Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Beyond Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Broken Hill Community Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Broken Hill Community Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Coastline Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Coastline Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Credit Union SA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Credit Union SA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Defence Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Defence Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Dnister Ukrainian Credit Co-operative']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Dnister Ukrainian Credit Co-operative</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='EECU']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EECU</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Fire Service Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Fire Service Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='First Choice Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='INC Invest']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">INC Invest</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Intech Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Intech Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.=&quot;People's Choice Credit Union&quot;]">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">People's Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Pulse Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Pulse Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Qudos Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Qudos Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Summerland Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Summerland Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@CountryOfIssue[.='AN']">
    <removed>
      <xsl:attribute name="name">CountryOfIssue</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AN</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/RelatedCompany/@RegisteredInCountry[.='AN']">
    <removed>
      <xsl:attribute name="name">RegisteredInCountry</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AN</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Beyond Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Beyond Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Broken Hill Community Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Broken Hill Community Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Coastline Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Coastline Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Credit Union SA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Credit Union SA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Defence Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Defence Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Dnister Ukrainian Credit Co-operative']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Dnister Ukrainian Credit Co-operative</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='EECU']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EECU</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Fire Service Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Fire Service Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='First Choice Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='INC Invest']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">INC Invest</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Intech Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Intech Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.=&quot;People's Choice Credit Union&quot;]">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">People's Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Pulse Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Pulse Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Qudos Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Qudos Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Summerland Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Summerland Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/@CountryEstablished[.='AN']">
    <removed>
      <xsl:attribute name="name">CountryEstablished</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AN</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Beyond Bank Australia']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Beyond Bank Australia</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Beyond Bank Australia</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Broken Hill Community Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Broken Hill Community Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Broken Hill Community Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Coastline Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Coastline Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Coastline Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Credit Union SA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Credit Union SA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Credit Union SA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Defence Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Defence Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Defence Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Dnister Ukrainian Credit Co-operative']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Dnister Ukrainian Credit Co-operative</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Dnister Ukrainian Credit Co-operative</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='EECU']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EECU</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EECU</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Fire Service Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Fire Service Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Fire Service Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='First Choice Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='INC Invest']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">INC Invest</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">INC Invest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Intech Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Intech Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Intech Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.=&quot;People's Choice Credit Union&quot;]">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">People's Choice Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">People's Choice Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Pulse Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Pulse Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Pulse Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Qudos Bank']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Qudos Bank</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Qudos Bank</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Summerland Credit Union']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Summerland Credit Union</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Summerland Credit Union</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/SchemaVersion/@LIXIVersion[.='2.1.0']">
    <updated>
      <xsl:attribute name="name">LIXIVersion</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">2.1.0</xsl:attribute>
      <xsl:attribute name="update">2.2.0</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
</xsl:stylesheet>
